=== modified file 'lib/canonical/launchpad/icing/style.css'
--- lib/canonical/launchpad/icing/style.css	2011-05-20 21:09:40 +0000
+++ lib/canonical/launchpad/icing/style.css	2011-05-27 22:55:25 +0000
@@ -556,6 +556,16 @@
   width: auto;
 }
 
+/* Gives us some room after the description of the user's subscription. */
+div#current_user_subscription {
+    padding-bottom: 8px;
+}
+
+/* This lets us have a link that spans lines. */
+div#current_user_subscription a.sprite {
+  display: inline;
+}
+
 /* === Translations === */
 
 .translation code {font-weight: bold;} /* an interpolation code, such as %i */

=== modified file 'lib/lp/bugs/browser/bug.py'
--- lib/lp/bugs/browser/bug.py	2011-05-20 14:48:53 +0000
+++ lib/lp/bugs/browser/bug.py	2011-05-27 22:55:25 +0000
@@ -37,6 +37,7 @@
     )
 from lazr.lifecycle.event import ObjectModifiedEvent
 from lazr.lifecycle.snapshot import Snapshot
+from lazr.restful.interfaces import IJSONRequestCache
 import pytz
 from zope import formlib
 from zope.app.form.browser import TextWidget
@@ -85,6 +86,7 @@
 from lp.app.widgets.itemswidgets import LaunchpadRadioWidgetWithDescription
 from lp.app.widgets.project import ProjectScopeWidget
 from lp.bugs.browser.widgets.bug import BugTagsWidget
+from lp.bugs.enum import BugNotificationLevel
 from lp.bugs.interfaces.bug import (
     IBug,
     IBugSet,
@@ -102,6 +104,7 @@
 from lp.bugs.interfaces.bugwatch import IBugWatchSet
 from lp.bugs.interfaces.cve import ICveSet
 from lp.bugs.mail.bugnotificationbuilder import format_rfc2822_date
+from lp.bugs.model.personsubscriptioninfo import PersonSubscriptions
 from lp.services import features
 from lp.services.fields import DuplicateBug
 from lp.services.propertycache import cachedproperty
@@ -285,13 +288,13 @@
         user = getUtility(ILaunchBag).user
         if self.context.bug.isMuted(user):
             text = "Unmute bug mail"
-            link = "+subscribe"
+            icon = 'yes'
         else:
             text = "Mute bug mail"
-            link = "+mute"
+            icon = 'no'
 
         return Link(
-            link, text, icon='remove', summary=(
+            '+mute', text, icon=icon, summary=(
                 "Mute this bug so that you will not receive emails "
                 "about it."))
 
@@ -504,47 +507,15 @@
         else:
             return 'subscribed-false %s' % dup_class
 
-    @property
-    def current_user_subscription_class(self):
-        bug = self.context
-
-        if bug.personIsSubscribedToDuplicate(self.user):
-            dup_class = 'dup-subscribed-true'
-        else:
-            dup_class = 'dup-subscribed-false'
-
-        if (bug.personIsDirectSubscriber(self.user) and not
-            bug.isMuted(self.user)):
-            return 'subscribed-true %s' % dup_class
-        else:
-            return 'subscribed-false %s' % dup_class
-
-    @property
-    def current_user_mute_class(self):
-        bug = self.context
-        subscription_class = self.current_user_subscription_class
-        if self.user_should_see_mute_link:
-            visibility_class = ''
-        else:
-            visibility_class = 'hidden'
-        if bug.isMuted(self.user):
-            return 'muted-true %s %s' % (subscription_class, visibility_class)
-        else:
-            return 'muted-false %s %s' % (
-                subscription_class, visibility_class)
-
     @cachedproperty
     def user_should_see_mute_link(self):
         """Return True if the user should see the Mute link."""
-        if features.getFeatureFlag('malone.advanced-subscriptions.enabled'):
-            user_is_subscribed = (
-                self.context.isMuted(self.user) or
-                self.context.isSubscribed(self.user) or
-                self.context.isSubscribedToDupes(self.user) or
-                self.context.personIsAlsoNotifiedSubscriber(self.user))
-            return user_is_subscribed
-        else:
-            return False
+        user_is_subscribed = (
+            self.context.isMuted(self.user) or
+            self.context.isSubscribed(self.user) or
+            self.context.isSubscribedToDupes(self.user) or
+            self.context.personIsAlsoNotifiedSubscriber(self.user))
+        return user_is_subscribed
 
     @cachedproperty
     def _bug_attachments(self):
@@ -643,6 +614,72 @@
         return ProxiedLibraryFileAlias(
             attachment.libraryfile, attachment).http_url
 
+class BugSubscriptionPortletView(BugView):
+
+    # We want these strings to be available for the template and for the
+    # JavaScript.
+    notifications_text = {
+        'not_only_other_subscription': _('You are'),
+        'only_other_subscription': _(
+            'You have subscriptions that may cause you to receive '
+            'notifications, but you are'),
+        'direct_all': _('subscribed to all notifications for this bug.'),
+        'direct_metadata': _(
+            'subscribed to all notifications except comments for this bug.'),
+        'direct_lifecycle': _(
+            'subscribed to notifications when this bug is closed or '
+            'reopened.'),
+        'not_direct': _(
+            "not directly subscribed to this bug's notifications."),
+        'muted': _(
+            'Your personal email notifications from this bug are muted.'),
+        }
+
+    def initialize(self):
+        """Initialize the view to handle the request."""
+        BugView.initialize(self)
+        user = self.user
+        # We are using "direct" to represent both direct and personal
+        # (not team).
+        self.direct_notifications = False
+        self.direct_all_notifications = False
+        self.direct_metadata_notifications = False
+        self.direct_lifecycle_notifications = False
+        self.other_subscription_notifications = False
+        self.only_other_subscription_notifications = False
+        self.any_subscription_notifications = False
+        self.muted = False
+        if user is not None:
+            bug = self.context
+            cache = IJSONRequestCache(self.request).objects
+            cache['notifications_text'] = self.notifications_text
+            self.muted = bug.isMuted(user)
+            psi = PersonSubscriptions(user, bug)
+            if psi.direct.personal:
+                self.direct_notifications = True
+                direct = psi.direct.personal[0]
+                cache['subscription'] = direct.subscription
+                level = direct.subscription.bug_notification_level
+                if level == BugNotificationLevel.COMMENTS:
+                    self.direct_all_notifications = True
+                elif level == BugNotificationLevel.METADATA:
+                    self.direct_metadata_notifications = True
+                else:
+                    assert level == BugNotificationLevel.LIFECYCLE
+                    self.direct_lifecycle_notifications = True
+            self.other_subscription_notifications = (
+                psi.from_duplicate.count or
+                psi.as_owner.count or
+                psi.as_assignee.count or
+                psi.direct.as_team_member or
+                psi.direct.as_team_admin)
+            cache['other_subscription_notifications'] = (
+                self.other_subscription_notifications
+            self.only_other_subscription_notifications = (
+                self.other_subscription_notifications and
+                not self.direct_notifications)
+            self.any_subscription_notifications = psi.count > 0
+
 
 class BugWithoutContextView:
     """View that redirects to the new bug page.

=== modified file 'lib/lp/bugs/browser/bugsubscription.py'
--- lib/lp/bugs/browser/bugsubscription.py	2011-05-24 19:33:23 +0000
+++ lib/lp/bugs/browser/bugsubscription.py	2011-05-27 22:55:25 +0000
@@ -171,6 +171,22 @@
         }
 
     @property
+    def direct_and_other_subscription_notifications(self):
+        user = self.user
+        if user is not None:
+            psi = PersonSubscriptions(user, self.context.bug)
+            direct_notifications = bool(psi.direct.personal)
+            other_subscription_notifications = (
+                psi.from_duplicate.count or
+                psi.as_owner.count or
+                psi.as_assignee.count or
+                psi.direct.as_team_member or
+                psi.direct.as_team_admin)
+            return (direct_notifications and
+                    other_subscription_notifications)
+        return False
+
+    @property
     def field_names(self):
         if self._use_advanced_features:
             return ['bug_notification_level']

=== modified file 'lib/lp/bugs/browser/configure.zcml'
--- lib/lp/bugs/browser/configure.zcml	2011-05-20 21:09:40 +0000
+++ lib/lp/bugs/browser/configure.zcml	2011-05-27 22:55:25 +0000
@@ -533,7 +533,7 @@
         </browser:pages>
         <browser:page
             for="lp.bugs.interfaces.bug.IBug"
-            class="lp.bugs.browser.bug.BugView"
+            class="lp.bugs.browser.bug.BugSubscriptionPortletView"
             permission="launchpad.View"
             name="+portlet-subscription"
             template="../templates/bug-portlet-subscription.pt"/>

=== modified file 'lib/lp/bugs/javascript/bugtask_index.js'
--- lib/lp/bugs/javascript/bugtask_index.js	2011-05-12 02:09:42 +0000
+++ lib/lp/bugs/javascript/bugtask_index.js	2011-05-27 22:55:25 +0000
@@ -1114,6 +1114,6 @@
                         "json-parse", "substitute", "widget-position-ext",
                         "lazr.formoverlay", "lazr.anim", "lazr.base",
                         "lazr.overlay", "lazr.choiceedit", "lp.app.picker",
-                        "lp.client", "escape",
-                        "lp.client.plugins", "lp.bugs.bugtask_index.portlets",
-                        "lp.bugs.subscriber", "lp.app.errors"]});
+                        "lp.client", "escape", "lp.client.plugins",
+                        "lp.bugs.subscriber", "lp.app.errors"],
+           "use": ["lp.bugs.bugtask_index.portlets"]});

=== modified file 'lib/lp/bugs/javascript/bugtask_index_portlets.js'
--- lib/lp/bugs/javascript/bugtask_index_portlets.js	2011-05-20 17:29:32 +0000
+++ lib/lp/bugs/javascript/bugtask_index_portlets.js	2011-05-27 22:55:25 +0000
@@ -246,157 +246,6 @@
     }, '.unsub-icon');
 }
 
-
-/**
- * We can have at most one advanced subscription overlay shown,
- * so we keep it globally to be able to clean-up before constructing
- * another one.
- */
-var subscription_overlay;
-
-/**
- * Cleans-up the existing subscription overlay (if any).
- */
-function remove_subscription_overlay() {
-    if (Y.Lang.isValue(subscription_overlay)) {
-        subscription_overlay.get('boundingBox').remove();
-    }
-    subscription_overlay = undefined;
-}
-
-/**
- * Creates and shows a new subscription overlay for the given subscription.
- */
-function create_new_subscription_overlay(subscription, header_text) {
-    remove_subscription_overlay();
-    subscription_overlay = setup_advanced_subscription_overlay(
-        subscription, header_text);
-    load_and_show_advanced_subscription_overlay(
-        subscription, subscription_overlay);
-}
-
-/*
- * Set up the handlers for the mute / unmute link.
- */
-function setup_mute_link_handlers() {
-    if (LP.links.me === undefined) {
-        return;
-    }
-    var link = Y.one('.menu-link-mute_subscription');
-    if (Y.Lang.isNull(link)) {
-        return;
-    }
-    link.addClass('js-action');
-    setup_client_and_bug();
-    link.on('click', _get_toggle_mute(link));
-}
-
-// This is a helper, factored out for reusability by setup_mute_link_handlers
-// and toggle_mute.
-function _get_toggle_mute(link) {
-    var parent_node = link.get('parentNode');
-    var spinner = Y.one('#mute-unmute-spinner');
-    var hide_spinner = function() {
-        link.set('display', 'inline');
-        spinner.set('display', 'none');
-    };
-    var handler = new Y.lp.client.ErrorHandler();
-    handler.showError = function(error_msg) {
-        Y.lp.app.errors.display_error(link, error_msg);
-    };
-    handler.clearProgressUI = hide_spinner;
-    return function (e) {
-        if (!Y.Lang.isUndefined(e)) {
-            e.halt();
-        }
-        var is_muted = parent_node.hasClass('muted-true');
-        var spinner_text, method_name;
-        if (! is_muted) {
-            spinner_text = 'Muting...';
-            method_name = 'mute';
-        } else {
-            spinner_text = 'Unmuting...';
-            method_name = 'unmute';
-        }
-        spinner.set('innerHTML', spinner_text);
-        link.set('display', 'none');
-        spinner.set('display', 'block');
-        var config = {
-            on: {
-                success: function(response) {
-                    is_muted = ! is_muted; // We successfully toggled.
-                    var subscription = get_subscribe_self_subscription();
-                    subscription.enable_spinner('Updating...');
-                    var subscription_link = subscription.get('link');
-                    var is_subscribed = false;
-                    var is_dupe_subscribed =
-                        subscription.has_duplicate_subscriptions();
-                    var label = subscription_labels.SUBSCRIBE;
-                    update_mute_after_subscription_change(is_muted);
-                    if (is_muted) {
-                        // Remove the subscriber's name from the subscriber
-                        // list, if it's there.
-                        Y.lp.bugs.subscribers_list.remove_user_link(
-                            subscription.get('subscriber'));
-                    } else {
-                        // When unmuting, the ``response`` is the previously
-                        // muted subscription, or null.
-                        is_subscribed = ! Y.Lang.isNull(response);
-                        if (is_subscribed) {
-                            subscription.set('is_direct', true);
-                            add_user_name_link(subscription);
-                            label = subscription_labels.EDIT;
-                        }
-                    }
-                    hide_spinner();
-                    Y.lazr.anim.green_flash({ node: parent_node }).run();
-                    set_subscription_link_parent_class(
-                        subscription_link, is_subscribed, is_dupe_subscribed);
-                    subscription.disable_spinner(label);
-                },
-                failure: handler.getFailureHandler()
-            },
-            parameters: {}
-        };
-        lp_client.named_post(bug_repr.self_link, method_name, config);
-    };
-}
-
-/*
- * Toggle the mute state.
- */
-
-function toggle_mute() {
-    if (LP.links.me === undefined) {
-        return;
-    }
-    var link = Y.one('.menu-link-mute_subscription');
-    if (Y.Lang.isNull(link)) {
-        return;
-    }
-    return _get_toggle_mute(link)();
-}
-
-/*
- * Update the Mute link after the user's subscriptions or mutes have
- * changed.
- */
-function update_mute_after_subscription_change(is_muted) {
-    var link = Y.one('.menu-link-mute_subscription');
-    var parent_node = link.get('parentNode');
-    if (Y.Lang.isUndefined(is_muted)) {
-        is_muted = parent_node.hasClass('muted-true');
-    }
-    parent_node.removeClass('hidden');
-    if (is_muted) {
-        parent_node.replaceClass('muted-false', 'muted-true');
-        link.set('innerHTML', "Unmute bug mail");
-    } else {
-        parent_node.replaceClass('muted-true', 'muted-false');
-        link.set('innerHTML', "Mute bug mail");
-    }
-}
-
 /*
  * Set up and return a Subscription object for the direct subscription
  * link.
@@ -463,37 +312,7 @@
 
     var subscription = get_subscribe_self_subscription();
 
-    if (subscription.is_node()) {
-        subscription.get('link').on('click', function(e) {
-            e.halt();
-            subscription.set('can_be_unsubscribed', true);
-            subscription.set('person', subscription.get('subscriber'));
-            subscription.set('is_team', false);
-            var parent = e.target.get('parentNode');
-            if (namespace.use_advanced_subscriptions) {
-                create_new_subscription_overlay(
-                    subscription, "Subscribe to bug");
-            } else {
-                // Look for the false conditions of subscription, which
-                // is_direct_subscription, etc. don't report correctly,
-                // to make sure we only use subscribe_current_user for
-                // the current user.
-                if (parent.hasClass('subscribed-false') &&
-                    parent.hasClass('dup-subscribed-false')) {
-                    subscribe_current_user(subscription);
-                }
-                else {
-                    unsubscribe_current_user(subscription);
-                }
-            }
-        });
-        subscription.get('link').addClass('js-action');
-    }
-
     setup_subscribe_someone_else_handler(subscription);
-    if (namespace.use_advanced_subscriptions) {
-        setup_mute_link_handlers();
-    }
 }
 
 function load_subscribers_from_duplicates() {
@@ -678,228 +497,6 @@
 }
 
 /*
- * Create and return a FormOverlay for advanced subscription
- * interactions.
- *
- * @method setup_advanced_subscription_overlay
- * @param subscription {Object} A Y.lp.bugs.subscriber.Subscription object.
- */
-function setup_advanced_subscription_overlay(subscription, text) {
-    var header = Y.Node.create('<h2 />').set('text', text);
-    var subscription_overlay = new Y.lazr.FormOverlay({
-        headerContent: header,
-        form_submit_button:
-            Y.Node.create(submit_button_html),
-        form_cancel_button:
-            Y.Node.create(cancel_button_html),
-        centered: true,
-        visible: false
-    });
-    subscription_overlay.render('#privacy-form-container');
-    return subscription_overlay;
-}
-
-/*
- * Load the content for and display the advanced subscription overlay.
- * The call to show() the overlay happens only when the form has been
- * loaded. That way the overlay won't appear empty.
- *
- * @method load_and_show_advanced_subscription_overlay
- * @param subscription {Object} A Y.lp.bugs.subscriber.Subscription object.
- * @param subscription_overlay {Object} A Y.lazr.FormOverlay to load
- *                                      content into.
- */
-function load_and_show_advanced_subscription_overlay(subscription,
-                                                     subscription_overlay) {
-    subscription.enable_spinner('Loading...');
-    subscription_overlay.set(
-        'form_submit_callback', function(form_data) {
-            handle_advanced_subscription_overlay(form_data);
-            subscription_overlay.hide();
-    });
-
-    var subscription_link_url = subscription.get(
-        'link').get('href') + '/++form++';
-    subscription_overlay.loadFormContentAndRender(subscription_link_url);
-
-    Y.on('contentready', function() {
-        Y.lp.bugs.bug_notification_level.setup();
-    }, '.bug-notification-level-field, .bug-subscription-basic');
-
-    // Show the overlay when the special event indicating that the form is
-    // ready to be displayed is received.
-    Y.on(['bugnotificationlevel:contentready', 'io:failure'], function() {
-        subscription.disable_spinner();
-        subscription_overlay.show();
-    });
-}
-
-/*
- * Subscribe the current user via the LP API.
- *
- * @method subscribe_current_user
- * @param subscription {Object} A Y.lp.bugs.subscriber.Subscription object.
- */
-function subscribe_current_user(subscription) {
-    subscription.enable_spinner('Subscribing...');
-    var subscription_link = subscription.get('link');
-    var subscriber = subscription.get('subscriber');
-    var bug_notification_level = subscription.get('bug_notification_level');
-
-    // This is always a direct subscription.
-    subscription.set('is_direct', true);
-
-    var error_handler = new Y.lp.client.ErrorHandler();
-    error_handler.clearProgressUI = function () {
-        subscription.disable_spinner();
-    };
-    error_handler.showError = function (error_msg) {
-        Y.lp.app.errors.display_error(subscription_link, error_msg);
-    };
-
-    var config = {
-        on: {
-            success: function(client) {
-                if (namespace.use_advanced_subscriptions) {
-                    subscription.disable_spinner(
-                        subscription_labels.EDIT);
-                } else {
-                    subscription.disable_spinner(
-                        subscription_labels.UNSUBSCRIBE);
-                }
-
-                if (subscription.has_duplicate_subscriptions()) {
-                    set_subscription_link_parent_class(
-                        subscription_link, true, true);
-                } else {
-                    set_subscription_link_parent_class(
-                        subscription_link, true, false);
-                }
-
-                // Handle the case where the subscriber's list displays
-                // "No subscribers."
-                var empty_subscribers = Y.one("#none-subscribers");
-                if (empty_subscribers) {
-                    var parent = empty_subscribers.get('parentNode');
-                    parent.removeChild(empty_subscribers);
-                }
-
-                add_user_name_link(subscription);
-                update_mute_after_subscription_change();
-
-                // Only when the link is added to the page, indicate success.
-                Y.on('contentready', function() {
-                    var flash_node = Y.one('.' + subscriber.get('css_name'));
-                    var anim = Y.lazr.anim.green_flash({ node: flash_node });
-                    anim.run();
-                }, '.' + subscriber.get('css_name'));
-            },
-
-            failure: error_handler.getFailureHandler()
-        },
-
-        parameters: {
-            person: Y.lp.client.get_absolute_uri(
-                subscriber.get('escaped_uri')),
-            suppress_notify: false,
-            level: bug_notification_level
-        }
-    };
-    lp_client.named_post(bug_repr.self_link, 'subscribe', config);
-}
-
-/*
- * Unsubscribe the current user via the LP API.
- *
- * @method unsubscribe_current_user
- * @param subscription {Object} A Y.lp.bugs.subscriber.Subscription object.
- */
-function unsubscribe_current_user(subscription) {
-    subscription.enable_spinner('Unsubscribing...');
-    var subscription_link = subscription.get('link');
-    var subscriber = subscription.get('subscriber');
-
-    var error_handler = new Y.lp.client.ErrorHandler();
-    error_handler.clearProgressUI = function () {
-        subscription.disable_spinner();
-    };
-    error_handler.showError = function (error_msg) {
-        Y.lp.app.errors.display_error(subscription_link, error_msg);
-    };
-
-    var subscriber_link = Y.lp.client.get_absolute_uri(
-        subscriber.get('escaped_uri'));
-    var config = {
-        on: {
-            success: function(client) {
-                // We need to track if this is direct or not,
-                // before we toggle the is_direct flag.
-                var original_is_direct = subscription.get('is_direct');
-
-                if (subscription.is_direct_subscription() &&
-                    subscription.has_duplicate_subscriptions()) {
-                    // Don't change the 'Unsubscribe' text if
-                    // dupe subscriptions remain.
-                    subscription.disable_spinner();
-                    set_subscription_link_parent_class(
-                        subscription_link, false, true);
-                    subscription.set('is_direct', false);
-                } else if (subscription.is_direct_subscription() &&
-                          !subscription.has_duplicate_subscriptions()) {
-                    // Only unsub'ing a direct subscriber here.
-                    subscription.disable_spinner(
-                        subscription_labels.SUBSCRIBE);
-                    set_subscription_link_parent_class(
-                        subscription_link, false, false);
-                    subscription.set('is_direct', false);
-                } else {
-                    // Only unsub'ing dupes here.
-                    subscription.disable_spinner(
-                        subscription_labels.SUBSCRIBE);
-                    set_subscription_link_parent_class(
-                        subscription_link, false, false);
-                    subscription.set('has_dupes', false);
-                }
-
-                var is_dupe = !original_is_direct;
-                Y.lp.bugs.subscribers_list.remove_user_link(
-                    subscriber, is_dupe);
-            },
-
-            failure: error_handler.getFailureHandler()
-        },
-
-        parameters: { person: subscriber_link }
-    };
-
-    // A team must be unsubcribed from both the current bug and from
-    // duplicates.  This configuration handles the first and then
-    // chains to the other upon success.
-    var team_config = {
-        on: {
-            success: function(client) {
-                lp_client.named_post(
-                    bug_repr.self_link, 'unsubscribeFromDupes', config);
-            },
-            failure: error_handler.getFailureHandler()
-        },
-        parameters: { person: subscriber_link }
-    };
-
-    if (subscription.is_team()){
-        lp_client.named_post(bug_repr.self_link, 'unsubscribe', team_config);
-    }
-    else {
-        if (subscription.is_direct_subscription()) {
-            lp_client.named_post(bug_repr.self_link, 'unsubscribe', config);
-        } else {
-            lp_client.named_post(
-                bug_repr.self_link, 'unsubscribeFromDupes', config);
-        }
-    }
-}
-
-/*
  * Initialize click handler for the subscribe someone else link.
  *
  * @method setup_subscribe_someone_else_handler
@@ -1137,113 +734,6 @@
     }
 }
 
-
-/*
- * Handle the advanced_subscription_overlay's form submissions.
- *
- * @method handle_advanced_subscription_overlay
- * @param form_data {Object} The data from the submitted form.
- */
-function handle_advanced_subscription_overlay(form_data) {
-    var subscription;
-    var mute_link = Y.one('.menu-link-mute_subscription');
-    var parent_node = mute_link.get('parentNode');
-    var is_muted = parent_node.hasClass('muted-true');
-    var requested_subscriber;
-    var request_for_self = false;
-    // XXX Danilo 20110422: this is a very lousy "special string"
-    // that will make it break for a team/person named 'update-subscription'.
-    // We should probably use special characters not allowed in team names
-    // (maybe all-uppercase would work).
-    var UPDATE_ACTION = 'update-subscription';
-
-    if (form_data['field.subscription'][0] === UPDATE_ACTION) {
-        requested_subscriber = LP.links.me;
-        request_for_self = true;
-    } else {
-        requested_subscriber = '/~' + form_data['field.subscription'][0];
-        if (requested_subscriber === LP.links.me) {
-            request_for_self = true;
-        }
-    }
-    if (request_for_self) {
-        subscription = get_subscribe_self_subscription();
-    } else {
-        subscription = get_team_subscription(requested_subscriber);
-    }
-    var link = subscription.get('link');
-    var link_parent = link.get('parentNode');
-
-    if (form_data['field.subscription'][0] === UPDATE_ACTION) {
-        // The user is already subscribed or is muted and wants to
-        // update their subscription.
-        setup_client_and_bug();
-        var person_name = subscription.get('person').get('name');
-        var subscription_url =
-            lp_bug_entry.get('self_link') + '/+subscription/' +
-            person_name;
-        config = {
-            on: {
-                success: function(lp_subscription) {
-                    subscription.enable_spinner('Updating subscription...');
-                    lp_subscription.set(
-                        'bug_notification_level',
-                        form_data['field.bug_notification_level'][0]);
-                    save_config = {
-                        on: {
-                            success: function(e) {
-                                subscription.disable_spinner(
-                                    'Edit subscription');
-                                link_parent.addClass('subscribed-true');
-                                link_parent.removeClass('subscribed-false');
-                                var anim = Y.lazr.anim.green_flash({
-                                    node: link_parent
-                                    });
-                                anim.run();
-                                if (is_muted) {
-                                    // We're going to assume that the user
-                                    // wants to unmute also, since they
-                                    // bothered to change their subscription.
-                                    toggle_mute();
-                                }
-                            },
-                            failure: function(e) {
-                                subscription.disable_spinner(
-                                    'Edit subscription');
-                                var anim = Y.lazr.anim.red_flash({
-                                    node: link_parent
-                                    });
-                                anim.run();
-                            }
-                        }
-                    };
-                    lp_subscription.lp_save(save_config);
-                }
-            }
-        };
-        lp_client.get(subscription_url, config);
-
-    } else if (link_parent.hasClass('subscribed-false') &&
-               link_parent.hasClass('dup-subscribed-false') &&
-               !is_muted && request_for_self) {
-        // The user isn't subscribed or muted, and the request is
-        // for himself (iow, not for a team).
-        subscription.set(
-            'bug_notification_level',
-            form_data['field.bug_notification_level']);
-        subscribe_current_user(subscription);
-    } else if (is_muted && request_for_self) {
-        // When a person has a bug muted, we show 2+ options:
-        // a. unmute, b. unmute and subscribe, c. unsubscribe team1...
-        // "b" is treated as 'update-subscription' case, and for any
-        // of the teams, request_for_self won't be true.
-        toggle_mute();
-    } else {
-        // Unsubscribe this person/team.
-        unsubscribe_current_user(subscription);
-    }
-}
-
 /*
  * Subscribe a person or team other than the current user.
  * This is a callback for the subscribe someone else picker.
@@ -1314,7 +804,6 @@
                             if (team_member) {
                                 subscription.set('can_be_unsubscribed', true);
                                 add_temp_user_name(subscription);
-                                update_mute_after_subscription_change();
                             } else {
                                 subscription.set(
                                    'can_be_unsubscribed', false);

=== added file 'lib/lp/bugs/javascript/bugtask_index_subscription_portlet.js'
--- lib/lp/bugs/javascript/bugtask_index_subscription_portlet.js	1970-01-01 00:00:00 +0000
+++ lib/lp/bugs/javascript/bugtask_index_subscription_portlet.js	2011-05-27 22:55:25 +0000
@@ -0,0 +1,146 @@
+/* Copyright 2011 Canonical Ltd.  This software is licensed under the
+ * GNU Affero General Public License version 3 (see the file LICENSE).
+ *
+ * Provide information and actions on all bug subscriptions a person holds.
+ *
+ * @module bugs
+ * @submodule bugtask_index_subscription_portlet
+ */
+
+YUI.add('lp.bugs.bugtask_index.portlets.subscription', function(Y) {
+
+var namespace = Y.namespace('lp.bugs.bugtask_index.portlets.subscription');
+
+function lp_client() {
+    // This is a hook point for tests.
+    if (!Y.Lang.isValue(namespace._lp_client)) {
+        namespace._lp_client = new Y.lp.client.Launchpad();
+    }
+    return namespace._lp_client;
+}
+
+/*
+ * Update the text and link at the top of the subscription portlet.
+ */
+function update_subscription_status() {
+    var status = Y.one('#current_user_subscription');
+    var span = status.one('span');
+    var link = status.one('a');
+    var mute_link = Y.one('.menu-link-mute_subscription');
+    var is_muted = (Y.Lang.isValue(mute_link) && mute_link.hasClass('yes'));
+    var messages = LP.cache.notifications_text;
+    if (is_muted) {
+        span.set('text', messages.muted);
+        if (!Y.Lang.isUndefined(link)) {
+            link.remove();
+        };
+    } else {
+        if (!Y.Lang.isValue(link)) {
+            // Make one.
+            link = Y.Node.create(
+                '<a class="menu-link-subscription sprite modify edit"/>');
+            link.set('href', LP.cache.context.web_link + '/+subscribe')
+            status.appendChild(link);
+            setup_subscription_link_handlers();
+        };
+        span.set('text', messages.not_only_other_subscription);
+        if (Y.Lang.isUndefined(LP.cache.subscription)) {
+            if (LP.cache.other_subscription_notifications) {
+                span.set('text', messages.only_other_subscription);
+            };
+            link.set('text', messages.not_direct);
+        } else {
+            switch (LP.cache.subscription.bug_notification_level) {
+                case 'Discussion':
+                    link.set('text', messages.direct_all);
+                    break;
+                case 'Details':
+                    link.set('text', messages.direct_metadata);
+                    break;
+                case 'Lifecycle':
+                    link.set('text', messages.direct_lifecycle);
+                    break;
+                default:
+                    Y.error(
+                        'Programmer error: unknown bug notification level: '+
+                        LP.cache.subscription.bug_notification_level);
+            };
+        };
+    };
+    Y.lazr.anim.green_flash({ node: status }).run();
+}
+namespace.update_subscription_status = update_subscription_status;
+
+var MUTED_CLASS = 'yes';
+var UNMUTED_CLASS = 'no';
+
+/*
+ * Set up the handlers for the mute / unmute link.
+ */
+function setup_mute_link_handlers() {
+    var link = Y.one('.menu-link-mute_subscription');
+    if (Y.Lang.isNull(link) || link.hasClass('spinner')) {
+        return;
+    }
+    link.addClass('js-action');
+    link.on('click', function (e) {
+        e.halt();
+        var is_muted = link.hasClass(MUTED_CLASS);
+        var method_name, current_class, destination_class;
+        if (is_muted) {
+            method_name = 'unmute';
+            current_class = MUTED_CLASS;
+            destination_class = UNMUTED_CLASS;
+        } else {
+            method_name = 'mute';
+            current_class = UNMUTED_CLASS;
+            destination_class = MUTED_CLASS;
+        }
+        link.replaceClass(current_class, 'spinner');
+        var handler = new Y.lp.client.ErrorHandler();
+        handler.showError = function(error_msg) {
+            Y.lp.app.errors.display_error(link.get('parentNode'), error_msg);
+        };
+        handler.clearProgressUI = function () {
+            link.replaceClass('spinner', current_class);
+        }
+        var config = {
+            on: {
+                success: function(response) {
+                    link.replaceClass('spinner', destination_class);
+                    update_subscription_status();
+                    Y.lazr.anim.green_flash(
+                        { node: link.get('parentNode') }).run();
+                },
+                failure: handler.getFailureHandler()
+            },
+            parameters: {}
+        };
+        lp_client().named_post(
+            LP.cache.context.bug_link, method_name, config);
+    });
+}
+namespace.setup_mute_link_handlers = setup_mute_link_handlers;
+
+function setup_subscription_link_handlers() {
+    var link = Y.one('#current_user_subscription a');
+    if (!Y.Lang.isValue(link)) {
+        return;
+    }
+    // XXX Add click handlers here.
+    link.addClass('js-action');
+}
+namespace.setup_subscription_link_handlers = setup_subscription_link_handlers;
+
+namespace.initialize = function () {
+    if (LP.links.me === undefined) {
+        return;
+    }
+    setup_subscription_link_handlers();
+    setup_mute_link_handlers();
+};
+
+}, '0.1', {requires: [
+    'dom', 'event', 'node', 'substitute', 'lazr.effects', 'lp.app.errors',
+    'lp.client'
+]});

=== added file 'lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.html'
--- lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.html	1970-01-01 00:00:00 +0000
+++ lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.html	2011-05-27 22:55:25 +0000
@@ -0,0 +1,42 @@
+<html>
+  <head>
+    <title>Bug subscriptions: descriptions and unsubscribe actions</title>
+
+     <!-- YUI 3.0 Setup -->
+    <script type="text/javascript"
+      src="../../../../canonical/launchpad/icing/yui/yui/yui.js"></script>
+    <script type="text/javascript"
+      src="../../../../canonical/launchpad/icing/lazr/build/lazr.js"></script>
+    <link rel="stylesheet"
+      href="../../../../canonical/launchpad/icing/yui/cssreset/reset.css"/>
+    <link rel="stylesheet"
+      href="../../../../canonical/launchpad/icing/yui/cssfonts/fonts.css"/>
+    <link rel="stylesheet"
+      href="../../../../canonical/launchpad/icing/yui/cssbase/base.css"/>
+    <link rel="stylesheet"
+      href="../../../../canonical/launchpad/javascript/test.css" />
+
+    <script type="text/javascript"
+      src="../../../app/javascript/client.js"></script>
+    <script type="text/javascript"
+      src="../../../app/javascript/errors.js"></script>
+
+    <!-- The module under test -->
+    <script type="text/javascript"
+      src="../bugtask_index_subscription_portlet.js"></script>
+
+    <!-- The test suite -->
+    <script type="text/javascript"
+      src="test_bugtask_index_subscription_portlet.js"></script>
+
+    <!-- Pretty up the sample html -->
+    <style type="text/css">
+      div#sample {margin:15px; width:200px; border:1px solid #999; padding:10px;}
+    </style>
+  </head>
+  <body class="yui3-skin-sam">
+
+    <!-- The test output -->
+    <div id="log"></div>
+  </body>
+</html>

=== added file 'lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.js'
--- lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.js	1970-01-01 00:00:00 +0000
+++ lib/lp/bugs/javascript/tests/test_bugtask_index_subscription_portlet.js	2011-05-27 22:55:25 +0000
@@ -0,0 +1,342 @@
+YUI({
+    base: '../../../../canonical/launchpad/icing/yui/',
+    filter: 'raw', combine: false, fetchCSS: false
+    }).use('test', 'console', 'lp.bugs.bugtask_index.portlets.subscription',
+           'node-event-simulate', function(Y) {
+
+var suite = new Y.Test.Suite(
+    "lp.bugs.bugtask_index.portlets.subscription Tests");
+var module = Y.lp.bugs.bugtask_index.portlets.subscription;
+
+/**
+ * XXX gary 2011-05-26 bug XXX
+ * LPClient is copied three times (see also test_structural_subscription.js
+ * and test_subscription.js).  It should be pushed to a shared test module.  
+ */
+function LPClient(){
+    if (!(this instanceof LPClient)) {
+        throw new Error("Constructor called as a function");
+    }
+    this.received = [];
+    // We create new functions every time because we allow them to be
+    // configured.
+    this.named_post = function(url, func, config) {
+        this._call('named_post', config, arguments);
+    };
+    this.patch = function(bug_filter, data, config) {
+        this._call('patch', config, arguments);
+    };
+}
+LPClient.prototype._call = function(name, config, args) {
+    this.received.push(
+        [name, Array.prototype.slice.call(args)]);
+    if (!Y.Lang.isValue(args.callee.args)) {
+        throw new Error("Set call_args on "+name);
+    }
+    var do_action = function () {
+        if (Y.Lang.isValue(args.callee.fail) && args.callee.fail) {
+            config.on.failure.apply(undefined, args.callee.args);
+        } else {
+            config.on.success.apply(undefined, args.callee.args);
+        }
+    };
+    if (Y.Lang.isValue(args.callee.halt) && args.callee.halt) {
+        args.callee.resume = do_action;
+    } else {
+        do_action();
+    }
+};
+
+function make_status_node() {
+    var status = Y.Node.create('<div/>')
+        .set('id', 'current_user_subscription')
+        .append(Y.Node.create('<span/>'));
+    Y.one('body').appendChild(status);
+    return status;
+}
+
+function add_link_to_status_node() {
+    var status = Y.one('#current_user_subscription');
+    status.append(
+        Y.Node.create('<a/>')
+            .addClass('menu-link-subscription')
+            .addClass('sprite')
+            .addClass('modify')
+            .addClass('edit')
+            .set('href', 'http://example.com')
+            .set('text', 'Example text')
+        );
+}
+
+function make_mute_node() {
+    var parent = Y.Node.create('<div/>')
+        .set('id', 'mute-link-container')
+        .append(Y.Node.create('<a/>')
+            .addClass('menu-link-mute_subscription')
+            .addClass('no')
+            .set('text', 'This is a mute link')
+            .set('href', 'http://www.example.com/+mute')
+        );
+    Y.one('body').appendChild(parent);
+    return parent;
+}
+
+function set_LP_cache(bug_link) {
+    window.LP = {cache: {
+        notifications_text: {
+            not_only_other_subscription: 'You are',
+            only_other_subscription: 
+                'You have subscriptions that may cause you to receive ' +
+                'notifications, but you are',
+            direct_all: 'subscribed to all notifications for this bug.',
+            direct_metadata: 
+                'subscribed to all notifications except comments for ' +
+                'this bug.',
+            direct_lifecycle: 
+                'subscribed to notifications when this bug is closed ' +
+                'or reopened.',
+            not_direct: 
+                "not directly subscribed to this bug's notifications.",
+            muted: 
+                'Your personal email notifications from this bug are muted.'
+            },
+        context: {web_link: 'http://example.com', bug_link: bug_link},
+        other_subscription_notifications: false
+        }};
+}
+
+// Notification levels.
+var COMMENTS = 'Discussion';
+var METADATA = 'Details';
+var LIFECYCLE = 'Lifecycle';
+
+function make_subscription(level) {
+    if (Y.Lang.isUndefined(level)) {
+        level = COMMENTS;
+    }
+    window.LP.cache.subscription = {'bug_notification_level': level};
+}
+
+/**
+ * Test update_subscription_status.
+ */
+suite.add(new Y.Test.Case({
+    name: 'Test update_subscription_status',
+
+    setUp: function() {
+        this.status_node = make_status_node();
+        this.mute_node = make_mute_node();
+        add_link_to_status_node();
+        set_LP_cache();
+    },
+
+    tearDown: function() {
+        this.status_node.remove();
+        this.mute_node.remove();
+        delete window.LP;
+    },
+
+    test_can_create_link: function() {
+        this.status_node.one('a').remove();
+        make_subscription();
+        Y.Assert.isTrue(Y.Lang.isNull(this.status_node.one('a')));
+        module.update_subscription_status()
+        var link = this.status_node.one('a');
+        Y.Assert.isTrue(Y.Lang.isValue(link));
+        Y.Assert.isTrue(link.hasClass('menu-link-subscription'));
+        Y.Assert.isTrue(link.hasClass('sprite'));
+        Y.Assert.isTrue(link.hasClass('modify'));
+        Y.Assert.isTrue(link.hasClass('edit'));
+        Y.Assert.isTrue(link.hasClass('js-action'));
+        Y.Assert.areEqual(
+            // window.LP.context.web_link + '/+subscribe',
+            'http://example.com/+subscribe',
+            link.get('href'));
+    },
+
+    test_no_subscription: function() {
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            "not directly subscribed to this bug's notifications.",
+            this.status_node.one('a').get('text'));
+    },
+
+    test_other_subscription: function() {
+        window.LP.cache.other_subscription_notifications = true;
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You have subscriptions that may cause you to receive ' +
+            'notifications, but you are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            "not directly subscribed to this bug's notifications.",
+            this.status_node.one('a').get('text'));
+    },
+
+    test_full_subscription: function() {
+        make_subscription(COMMENTS);
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            "subscribed to all notifications for this bug.",
+            this.status_node.one('a').get('text'));
+    },
+
+    test_metadata_subscription: function() {
+        make_subscription(METADATA);
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            'subscribed to all notifications except comments for this bug.',
+            this.status_node.one('a').get('text'));
+    },
+
+    test_lifecycle_subscription: function() {
+        make_subscription(LIFECYCLE);
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            'subscribed to notifications when this bug is closed or ' +
+            'reopened.',
+            this.status_node.one('a').get('text'));
+    },
+
+    test_direct_subscription_has_precedence: function() {
+        window.LP.cache.other_subscription_notifications = true;
+        make_subscription(LIFECYCLE);
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            'subscribed to notifications when this bug is closed or ' +
+            'reopened.',
+            this.status_node.one('a').get('text'));
+    },
+
+    test_muted_subscription: function() {
+        make_subscription(LIFECYCLE);
+        this.mute_node.one('a').replaceClass('no', 'yes');
+        Y.Assert.isTrue(Y.Lang.isValue(this.status_node.one('a')));
+        module.update_subscription_status()
+        Y.Assert.areEqual(
+            'Your personal email notifications from this bug are muted.',
+            this.status_node.one('span').get('text'));
+        Y.Assert.isFalse(Y.Lang.isValue(this.status_node.one('a')));
+    }
+
+}));
+
+/**
+ * Test setup_mute_link_handlers.
+ */
+suite.add(new Y.Test.Case({
+    name: 'Test setup_mute_link_handlers',
+
+    setUp: function() {
+        this.status_node = make_status_node();
+        this.mute_node = make_mute_node();
+        this.link = this.mute_node.one('a');
+        add_link_to_status_node();
+        this.bug_link = 'http://example.net/firefox/bug/1';
+        set_LP_cache(this.bug_link);
+        make_subscription(COMMENTS);
+        module.update_subscription_status();
+        module.setup_mute_link_handlers();
+        module._lp_client = new LPClient();
+        module._lp_client.named_post.args = [];
+    },
+
+    tearDown: function() {
+        this.status_node.remove();
+        this.mute_node.remove();
+        delete window.LP;
+        delete module._lp_client;
+        var error_overlay = Y.one('.yui3-lazr-formoverlay');
+        if (Y.Lang.isValue(error_overlay)) {
+            error_overlay.remove();
+        }
+    },
+
+    test_mute_success: function() {
+        this.link.simulate('click');
+        Y.Assert.areEqual(1, module._lp_client.received.length);
+        Y.Assert.areEqual('named_post', module._lp_client.received[0][0]);
+        var args = module._lp_client.received[0][1];
+        Y.Assert.areEqual(this.bug_link, args[0]);
+        Y.Assert.areEqual('mute', args[1]);
+        Y.ObjectAssert.areEqual({}, args[2].parameters);
+        Y.Assert.isTrue(this.link.hasClass('yes'));
+        Y.Assert.isFalse(this.link.hasClass('spinner'));
+        Y.Assert.isFalse(this.link.hasClass('no'));
+        Y.Assert.areEqual(
+            'Your personal email notifications from this bug are muted.',
+            this.status_node.one('span').get('text'));
+    },
+
+    test_unmute_success: function() {
+        this.link.replaceClass('no', 'yes');
+        this.link.simulate('click');
+        Y.Assert.areEqual(1, module._lp_client.received.length);
+        Y.Assert.areEqual('named_post', module._lp_client.received[0][0]);
+        var args = module._lp_client.received[0][1];
+        Y.Assert.areEqual(this.bug_link, args[0]);
+        Y.Assert.areEqual('unmute', args[1]);
+        Y.ObjectAssert.areEqual({}, args[2].parameters);
+        Y.Assert.isTrue(this.link.hasClass('no'));
+        Y.Assert.isFalse(this.link.hasClass('spinner'));
+        Y.Assert.isFalse(this.link.hasClass('yes'));
+        Y.Assert.areEqual(
+            'You are',
+            this.status_node.one('span').get('text'));
+        Y.Assert.areEqual(
+            "subscribed to all notifications for this bug.",
+            this.status_node.one('a').get('text'));
+    },
+
+    test_mute_spinner_and_failure: function() {
+        module._lp_client.named_post.fail = true;
+        module._lp_client.named_post.args = [
+            true,
+            {status: 400, responseText: 'Rutebegas!'}];
+        module._lp_client.named_post.halt = true;
+        this.link.simulate('click');
+        // Right now, this is as if we are waiting for the server to
+        // reply. The link is spinning.
+        Y.Assert.isTrue(this.link.hasClass('spinner'));
+        Y.Assert.isFalse(this.link.hasClass('no'));
+        // Now the server replies with an error.
+        module._lp_client.named_post.resume();
+        // We have no spinner.
+        Y.Assert.isTrue(this.link.hasClass('no'));
+        Y.Assert.isFalse(this.link.hasClass('spinner'));
+        // The page has rendered the error overlay.
+        var error_box = Y.one('.yui3-lazr-formoverlay-errors');
+    }
+
+}));
+
+
+Y.Test.Runner.on('complete', function(data) {
+    status_node = Y.Node.create(
+        '<p id="complete">Test status: complete</p>');
+    Y.one('body').appendChild(status_node);
+    });
+Y.Test.Runner.add(suite);
+
+var console = new Y.Console({newestOnTop: false});
+console.render('#log');
+
+Y.on('domready', function() {
+    Y.Test.Runner.run();
+});
+});

=== modified file 'lib/lp/bugs/javascript/tests/test_subscription.js'
--- lib/lp/bugs/javascript/tests/test_subscription.js	2011-04-25 13:33:31 +0000
+++ lib/lp/bugs/javascript/tests/test_subscription.js	2011-05-27 22:55:25 +0000
@@ -8,8 +8,10 @@
 var module = Y.lp.bugs.subscription;
 
 /**
- * LPClient is taken from test_structural_subscription.js.
- * It maybe should be pushed to a shared test module.
+ * XXX gary 2011-05-26 bug XXX
+ * LPClient is copied three times (see also test_structural_subscription.js
+ * and test_bugtask_index_subscription_portlet.js).  It should be pushed to a
+ * shared test module.  
  */
 function LPClient(){
     if (!(this instanceof LPClient)) {

=== modified file 'lib/lp/bugs/templates/bug-portlet-subscription.pt'
--- lib/lp/bugs/templates/bug-portlet-subscription.pt	2011-05-20 21:09:40 +0000
+++ lib/lp/bugs/templates/bug-portlet-subscription.pt	2011-05-27 22:55:25 +0000
@@ -8,27 +8,52 @@
 >
   <div class="section" tal:define="context_menu context/menu:context"
        metal:define-slot="heading">
-    <div
-      tal:attributes="class view/current_user_subscription_class"
-      tal:content="structure context_menu/subscription/render" />
+    <div id="current_user_subscription"
+         tal:attributes="class python:view.other_subscription_notifications
+                         and 'has_other_subscriptions'">
+      <tal:block condition="not:view/muted">
+        <span tal:condition="not:view/only_other_subscription_notifications"
+              tal:content="view/notifications_text/not_only_other_subscription">
+        You are
+        </span>
+        <span tal:condition="view/only_other_subscription_notifications"
+              tal:content="view/notifications_text/only_other_subscription" />
+        <a tal:attributes="href string:${view/current_bugtask/fmt:url}/+subscribe"
+           class="menu-link-subscription sprite modify edit">
+           <tal:text condition="view/direct_all_notifications"
+                     replace="view/notifications_text/direct_all">
+           subscribed to all notifications for this bug.
+           </tal:text>
+           <tal:text condition="view/direct_metadata_notifications"
+                     replace="view/notifications_text/direct_metadata" />
+           <tal:text condition="view/direct_lifecycle_notifications"
+                     replace="view/notifications_text/direct_lifecycle" />
+           <tal:text condition="not:view/direct_notifications"
+                     replace="view/notifications_text/not_direct" />
+        </a>
+      </tal:block>
+      <span tal:condition="view/muted"
+            tal:content="view/notifications_text/muted" />
+    </div>
     <div id="sub-unsub-spinner">Subscribing...</div>
-    <div tal:condition="request/features/malone.advanced-structural-subscriptions.enabled"
-        tal:content="structure context_menu/editsubscriptions/render" />
     <tal:show-mute condition="
         request/features/malone.advanced-subscriptions.enabled">
-      <div tal:attributes="class view/current_user_mute_class"
+      <div tal:attributes="class python:
+                'hidden' if not view.user_should_see_mute_link else None"
            id="mute-link-container">
         <span tal:replace="structure context_menu/mute_subscription/render"
         />&nbsp;<a target="help" class="sprite maybe mute-help"
             href="/+help/subscription-mute.html"
           >&nbsp;<span class="invisible-link">Mute help</span></a>
-        <div style="float: left" id="mute-unmute-spinner">Unmuting...</div>
       </div>
     </tal:show-mute>
+    <div tal:condition="request/features/malone.advanced-structural-subscriptions.enabled"
+        tal:content="structure context_menu/editsubscriptions/render" />
   </div>
   <script type="text/javascript">
     LPS.use('io-base', 'node',
-            'lp.bugs.bugtask_index.portlets', function(Y) {
+            'lp.bugs.bugtask_index.portlets',
+            'lp.bugs.bugtask_index.portlets.subscription', function(Y) {
         // Must be done inline here to ensure the load event fires.
         // This is a work around for a YUI3 issue with event handling.
         var subscription_link = Y.one('.menu-link-subscription');
@@ -39,10 +64,11 @@
         }
 
         Y.on('domready', function() {
-            if (Y.lp.bugs.bugtask_index.portlets) {
-                Y.lp.bugs.bugtask_index.portlets.load_subscribers_portlet(
-                    subscription_link, subscription_link_handler);
-            }
+            lp.bugs.bugtask_index.portlets.subscription.initialize();
+            Y.lp.bugs.bugtask_index.portlets.load_subscription_portlet(
+                subscription_link, subscription_link_handler);
+            Y.lp.bugs.bugtask_index.portlets.load_subscribers_portlet(
+                subscription_link, subscription_link_handler);
         });
     });
   </script>

=== modified file 'lib/lp/bugs/templates/bug-subscription.pt'
--- lib/lp/bugs/templates/bug-subscription.pt	2011-05-06 15:40:47 +0000
+++ lib/lp/bugs/templates/bug-subscription.pt	2011-05-27 22:55:25 +0000
@@ -60,6 +60,14 @@
           duplicates.
         </p>
 
+        <p tal:condition="view/direct_and_other_subscription_notifications"
+           class="warning message">
+          You have other subscriptions that may send you notifications from
+          this bug, so removing your direct subscription may not stop all
+          email about this bug.  Mute this bug to make sure you do not receive
+          email about it (except potentially from team mailing lists).
+        </p>
+
         <div metal:use-macro="context/@@launchpad_form/form">
         </div>
 

=== modified file 'lib/lp/bugs/templates/bugtask-index.pt'
--- lib/lp/bugs/templates/bugtask-index.pt	2011-05-20 21:09:40 +0000
+++ lib/lp/bugs/templates/bugtask-index.pt	2011-05-27 22:55:25 +0000
@@ -43,9 +43,9 @@
       </tal:if>
       <script type="text/javascript">
         LPS.use('base', 'node', 'oop', 'event', 'lp.bugs.bugtask_index',
-                  'lp.bugs.bugtask_index.portlets',
-                  'lp.code.branchmergeproposal.diff', 'lp.comments.hide',
-                  function(Y) {
+                'lp.bugs.bugtask_index.portlets',
+                'lp.code.branchmergeproposal.diff', 'lp.comments.hide',
+                function(Y) {
             Y.lp.bugs.bugtask_index.portlets.use_advanced_subscriptions =
                 use_advanced_subscriptions;
             Y.lp.bugs.bugtask_index.setup_bugtask_index();

